@@ -59,12 +59,12 @@ locale <- function(date_names = "en",
   }
 
   stopifnot(decimal_mark %in% c(".", ","))
-  stopifnot(is.character(grouping_mark), length(grouping_mark) == 1)
+  check_string(grouping_mark)
   if (decimal_mark == grouping_mark) {
     stop("`decimal_mark` and `grouping_mark` must be different", call. = FALSE)
   }
 
-  check_tz(tz)
+  tz <- check_tz(tz)
   check_encoding(encoding)
 
   structure(
@@ -86,8 +86,10 @@ is.locale <- function(x) inherits(x, "locale")
 #' @export
 print.locale <- function(x, ...) {
   cat("<locale>\n")
-  cat("Numbers:  ", prettyNum(123456.78, big.mark = x$grouping_mark,
-    decimal.mark = x$decimal_mark, digits = 8), "\n", sep = "")
+  cat("Numbers:  ", prettyNum(123456.78,
+    big.mark = x$grouping_mark,
+    decimal.mark = x$decimal_mark, digits = 8
+  ), "\n", sep = "")
   cat("Formats:  ", x$date_format, " / ", x$time_format, "\n", sep = "")
   cat("Timezone: ", x$tz, "\n", sep = "")
   cat("Encoding: ", x$encoding, "\n", sep = "")
@@ -107,21 +109,29 @@ default_locale <- function() {
 }
 
 check_tz <- function(x) {
-  stopifnot(is.character(x), length(x) == 1)
+  check_string(x, nm = "tz")
 
-  if (identical(x, ""))
-    return(TRUE)
+  if (identical(x, "")) {
+    x <- Sys.timezone()
 
-  if (x %in% OlsonNames())
-    return(TRUE)
+    if (identical(x, "") || identical(x, NA_character_)) {
+      x <- "UTC"
+    }
+  }
 
-  stop("Unknown TZ ", x, call. = FALSE)
+  if (x %in% tzdb::tzdb_names()) {
+    x
+  } else {
+    stop("Unknown TZ ", x, call. = FALSE)
+  }
 }
-check_encoding <- function(x) {
-  stopifnot(is.character(x), length(x) == 1)
 
-  if (tolower(x) %in% tolower(iconvlist()))
+check_encoding <- function(x) {
+  check_string(x, nm = "encoding")
+
+  if (tolower(x) %in% tolower(iconvlist())) {
     return(TRUE)
+  }
 
   stop("Unknown encoding ", x, call. = FALSE)
 }
