@@ -5,13 +5,13 @@
 #include "DateTime.h"
 
 [[cpp11::register]] cpp11::writable::doubles utctime_(
-    cpp11::integers year,
-    cpp11::integers month,
-    cpp11::integers day,
-    cpp11::integers hour,
-    cpp11::integers min,
-    cpp11::integers sec,
-    cpp11::doubles psec) {
+    const cpp11::integers& year,
+    const cpp11::integers& month,
+    const cpp11::integers& day,
+    const cpp11::integers& hour,
+    const cpp11::integers& min,
+    const cpp11::integers& sec,
+    const cpp11::doubles& psec) {
   int n = year.size();
   if (month.size() != n || day.size() != n || hour.size() != n ||
       min.size() != n || sec.size() != n || psec.size() != n) {
@@ -22,14 +22,7 @@
 
   for (int i = 0; i < n; ++i) {
     DateTime dt(
-        year[i],
-        month[i] - 1,
-        day[i] - 1,
-        hour[i],
-        min[i],
-        sec[i],
-        psec[i],
-        "UTC");
+        year[i], month[i], day[i], hour[i], min[i], sec[i], psec[i], "UTC");
     out[i] = dt.datetime();
   }
 
